@@ -1,14 +1,12 @@
 [+ autogen5 template +]
+[+INCLUDE (string-append "licenses/" (get "License") ".tpl") \+]
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * [+NameLower+].c
- * Copyright (C) [+Author+] [+(shell "date +%Y")+] <[+Email+]>
+ * Copyright (C) [+(shell "date +%Y")+] [+Author+] <[+Email+]>
  * 
-[+CASE (get "License") +]
-[+ == "BSD"  +][+(bsd  (get "Name") (get "Author") " * ")+]
-[+ == "LGPL" +][+(lgpl (get "Name") (get "Author") " * ")+]
-[+ == "GPL"  +][+(gpl  (get "Name")                " * ")+]
-[+ESAC+] */
+[+INVOKE LICENSE-DESCRIPTION PFX=" * " PROGRAM=(get "Name") OWNER=(get "Author") \+]
+ */
 #include "[+NameLower+].h"
 [+IF (=(get "HaveI18n") "1")+]
 #include <glib/gi18n.h>
@@ -23,6 +21,16 @@
 
 G_DEFINE_TYPE ([+NameCClass+], [+NameCLower+], GTK_TYPE_APPLICATION);
 
+[+IF (=(get "HaveBuilderUI") "1")+]
+/* Define the private structure in the .c file */
+#define [+NameCUpper+]_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), [+NameCUpper+]_TYPE_APPLICATION, [+NameCClass+]Private))
+
+struct _[+NameCClass+]Private
+{
+	/* ANJUTA: Widgets declaration for [+NameHLower+].ui - DO NOT REMOVE */
+};
+[+ENDIF+]
+
 /* Create a new window loading a file */
 static void
 [+NameCLower+]_new_window (GApplication *app,
@@ -33,6 +41,8 @@ static void
 	GtkBuilder *builder;
 	GError* error = NULL;
 
+	[+NameCClass+]Private *priv = [+NameCUpper+]_GET_PRIVATE(app);
+
 	/* Load UI from file */
 	builder = gtk_builder_new ();
 	if (!gtk_builder_add_from_file (builder, UI_FILE, &error))
@@ -42,7 +52,7 @@ static void
 	}
 
 	/* Auto-connect signal handlers */
-	gtk_builder_connect_signals (builder, NULL);
+	gtk_builder_connect_signals (builder, app);
 
 	/* Get the window object from the ui file */
 	window = GTK_WIDGET (gtk_builder_get_object (builder, TOP_WINDOW));
@@ -52,6 +62,10 @@ static void
 				TOP_WINDOW,
 				UI_FILE);
         }
+
+	
+	/* ANJUTA: Widgets initialization for [+NameHLower+].ui - DO NOT REMOVE */
+
 	g_object_unref (builder);
 [+ELSE+]
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -104,7 +118,9 @@ static void
 {
 	G_APPLICATION_CLASS (klass)->activate = [+NameCLower+]_activate;
 	G_APPLICATION_CLASS (klass)->open = [+NameCLower+]_open;
-
+[+IF (=(get "HaveBuilderUI") "1")+]
+	g_type_class_add_private (klass, sizeof ([+NameCClass+]Private));
+[+ENDIF+]
 	G_OBJECT_CLASS (klass)->finalize = [+NameCLower+]_finalize;
 }
 
